<?php

/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined('ABSPATH') || exit;

get_header();
get_template_part('template-parts/banner/content', 'banner-blog');
/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
do_action('woocommerce_before_main_content');
$shop_page_sidebar = aggen_option('shop_sidebar');


if (isset($_GET['shop-sidebar']) && $_GET['shop-sidebar'] != '') {
	$shop_page_sidebar = sanitize_text_field($_GET['shop-sidebar']);
}

?>

<?php
if (function_exists('aggen_title')) {
	aggen_title();
}
?>
<div class="content-area section-padding">
	<div class="container">
		<div class="row">
			<?php if (is_active_sidebar('shop-sidebar') && $shop_page_sidebar == 'left') : ?>
				<div class="col-md-3 col-xs-12">
					<div class="widget-area sm-mt50 xs-mt30">
						<?php dynamic_sidebar('shop-sidebar');  ?>
					</div>
				</div>
			<?php endif;  ?>
			<?php if (is_active_sidebar('shop-sidebar') && $shop_page_sidebar != 'no') : ?>
				<div class="col-md-9">
				<?php else : ?>
					<div class="col-md-12">
					<?php endif; ?>

					<?php
					if (woocommerce_product_loop()) {

						/**
						 * Hook: woocommerce_before_shop_loop.
						 *
						 * @hooked woocommerce_output_all_notices - 10
						 * @hooked woocommerce_result_count - 20
						 * @hooked woocommerce_catalog_ordering - 30
						 */
						do_action('woocommerce_before_shop_loop');  ?>
						<div class="product-filter-and-order">
							<?php
							woocommerce_result_count();
							woocommerce_catalog_ordering();
							?>
						</div>
					<?php
						woocommerce_product_loop_start();

						if (wc_get_loop_prop('total')) {
							while (have_posts()) {
								the_post();

								/**
								 * Hook: woocommerce_shop_loop.
								 *
								 * @hooked WC_Structured_Data::generate_product_data() - 10
								 */
								do_action('woocommerce_shop_loop');

								wc_get_template_part('content', 'product');
							}
						}

						woocommerce_product_loop_end();

						/**
						 * Hook: woocommerce_after_shop_loop.
						 *
						 * @hooked woocommerce_pagination - 10
						 */
						do_action('woocommerce_after_shop_loop');
					} else {
						/**
						 * Hook: woocommerce_no_products_found.
						 *
						 * @hooked wc_no_products_found - 10
						 */
						do_action('woocommerce_no_products_found');
					}

					?>
					</div>
					<?php if (is_active_sidebar('shop-sidebar') && $shop_page_sidebar == 'right') : ?>
						<div class="col-md-3 col-xs-12">
							<div class="widget-area sm-mt50 xs-mt30">
								<?php dynamic_sidebar('shop-sidebar');  ?>
							</div>
						</div>
					<?php endif;  ?>
				</div>
		</div>
	</div>
	<?php
	/**
	 * Hook: woocommerce_after_main_content.
	 *
	 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
	 */
	do_action('woocommerce_after_main_content');

	get_footer('shop');
